var conn = new WebIM.connection({
    isMultiLoginSessions: WebIM.config.isMultiLoginSessions,
    https: typeof WebIM.config.https === 'boolean' ? WebIM.config.https : location.protocol === 'https:',
    url: WebIM.config.xmppURL,
    heartBeatWait: WebIM.config.heartBeatWait,
    autoReconnectNumMax: WebIM.config.autoReconnectNumMax,
    autoReconnectInterval: WebIM.config.autoReconnectInterval,
    apiUrl: WebIM.config.apiURL,
    isAutoLogin: true
});

conn.listen({
    onOpened: function (message) {          //连接成功回调
        // 如果isAutoLogin设置为false，那么必须手动设置上线，否则无法收消息
        // 手动上线指的是调用conn.setPresence(); 如果conn初始化时已将isAutoLogin设置为true
        // 则无需调用conn.setPresence();          
    },
    onClosed: function (message) { },         //连接关闭回调
    onTextMessage: function (message) { },    //收到文本消息
    onEmojiMessage: function (message) { },   //收到表情消息
    onPictureMessage: function (message) { }, //收到图片消息
    onCmdMessage: function (message) { },     //收到命令消息
    onAudioMessage: function (message) { },   //收到音频消息
    onLocationMessage: function (message) { },//收到位置消息
    onFileMessage: function (message) { },    //收到文件消息
    onVideoMessage: function (message) {
        var node = document.getElementById('privateVideo');
        var option = {
            url: message.url,
            headers: {
                'Accept': 'audio/mp4'
            },
            onFileDownloadComplete: function (response) {
                var objectURL = WebIM.utils.parseDownloadResponse.call(conn, response);
                node.src = objectURL;
            },
            onFileDownloadError: function () {
                console.log('File down load error.')
            }
        };
        WebIM.utils.download.call(conn, option);
    },   //收到视频消息
    onPresence: function (message) { },       //处理“广播”或“发布-订阅”消息，如联系人订阅请求、处理群组、聊天室被踢解散等消息
    onRoster: function (message) { },         //处理好友申请
    onInviteMessage: function (message) { },  //处理群组邀请
    onOnline: function () { },                  //本机网络连接成功
    onOffline: function () { },                 //本机网络掉线
    onError: function (message) { },          //失败回调
    onBlacklistUpdate: function (list) {       //黑名单变动
        // 查询黑名单，将好友拉黑，将好友从黑名单移除都会回调这个函数，list则是黑名单现有的所有好友信息
        console.log(list);
    },
    onReceivedMessage: function (message) { },    //收到消息送达服务器回执
    onDeliveredMessage: function (message) { },   //收到消息送达客户端回执
    onReadMessage: function (message) { },        //收到消息已读回执
    onCreateGroup: function (message) { },        //创建群组成功回执（需调用createGroupNew）
    onMutedMessage: function (message) { }        //如果用户在A群组被禁言，在A群发消息会走这个回调并且消息不会传递给群其它成员
});

// 操作文件对象转换方法

function dataURLtoBlob(dataurl) {
    var arr = dataurl.split(',');
    var mime = arr[0].match(/:(.*?);/)[1];
    var bstr = atob(arr[1]);
    var n = bstr.length;
    var u8arr = new Uint8Array(n);
    while (n--) {
        u8arr[n] = bstr.charCodeAt(n);
    }
    return new Blob([u8arr], { type: mime });
}

//实现将项目的图片转化成base64
function convertImgToBase64(url, callback, outputFormat) {
    var canvas = document.createElement('CANVAS'),
        ctx = canvas.getContext('2d'),
        img = new Image;
    img.crossOrigin = 'Anonymous';
    img.onload = function () {
        // canvas.height = img.height;
        // canvas.width = img.width;
        var rate = img.height/img.width;
        canvas.width = 1080;
        canvas.height = canvas.width*rate;
        ctx.drawImage(img, 0, 0, canvas.width, canvas.height);
        var dataURL = canvas.toDataURL(outputFormat || 'image/jpeg', 0.5);
        callback.call(this, dataURL);
        canvas = null;
    };
    img.src = url;
}



//将base64转换为文件
function dataURLtoFile(dataurl, filename) {
    var arr = dataurl.split(','), mime = arr[0].match(/:(.*?);/)[1],
        bstr = atob(arr[1]), n = bstr.length, u8arr = new Uint8Array(n);
    while (n--) {
        u8arr[n] = bstr.charCodeAt(n);
    }
    return new File([u8arr], filename, { type: mime });
}

// mpeg
function dataURL2Audio(base64Str1, callback) {
    if (base64Str1.indexOf('data:audio/amr;base64,') > 0) {
        console.log('amr' + base64Str1);
        var base64Str = base64Str1.replace('data:audio/amr;base64,', '');
        var audioName = (new Date()).valueOf() + '.amr';
    } else {
        console.log('mpeg' + base64Str1);
        var base64Str = base64Str1.replace('data:audio/mpeg;base64,', '');
        var audioName = (new Date()).valueOf() + '.wav';
    }
    plus.io.requestFileSystem(plus.io.PRIVATE_DOC, function (fs) {
        fs.root.getFile(audioName, { create: true }, function (entry) {
            // 获得平台绝对路径
            var fullPath = entry.fullPath;
            if (mui.os.android) {
                // 读取音频
                var Base64 = plus.android.importClass("android.util.Base64");
                var FileOutputStream = plus.android.importClass("java.io.FileOutputStream");
                try {
                    var out = new FileOutputStream(fullPath);
                    var bytes = Base64.decode(base64Str, Base64.DEFAULT);
                    out.write(bytes);
                    out.close();
                    // 回调
                    callback && callback(entry);
                } catch (e) {
                    console.log(e.message);
                }
            } else if (mui.os.ios) {
                var NSData = plus.ios.importClass('NSData');
                var nsData = new NSData();
                nsData = nsData.initWithBase64EncodedStringoptions(base64Str, 0);
                console.log('读取出来' + nsData);
                if (nsData) {
                    nsData.plusCallMethod({ writeToFile: fullPath, atomically: true });
                    plus.ios.deleteObject(nsData);
                }
                // 回调
                callback && callback(entry);
            }
        })
    })
}
// 储存聊天记录
function storeChat (opt) {
    myHttp('/regBackup/backup', opt, 'GET', function (result) {
        if (result) {
            // 成功
        } else {
            // 失败
            console.log('聊天消息保存失败');
        }
    });
}
