

//初始化数据库indexedDb
function initIndexedDb(currentUser, callback) {
    // 新建或读取indexedDb数据库
    request = window.indexedDB.open(currentUser);
    request.onerror = function (event) {
        console.log('数据库打开报错');
    };
    request.onsuccess = function (event) {
        db = request.result;
        callback(db);
        console.log('数据库打开成功');
    };
    // 如果不存在新建数据库
    request.onupgradeneeded = function (event) {
        console.log('新建数据库成功');
        db = event.target.result;
        var objectStore;
        if (!db.objectStoreNames.contains(currentUser)) {
            objectStore = db.createObjectStore(currentUser, {
                keyPath: "serverId"
            });
            objectStore.createIndex('otherSide', 'otherSide', { unique: false });
        }
    }
};

// 新增数据库数据
function addBd(currentUser, data) {
    var request = db.transaction(currentUser, 'readwrite')
        .objectStore(currentUser)
        .add(data);
    request.onsuccess = function (event) {
        console.log('watcher数据写入成功');
    };

    request.onerror = function (event) {
        console.log('数据写入失败');
    }
}
// 修改数据
function update(db, currentUser, primaryKey, result, callback) {
    // 编辑数据
    var transaction = db.transaction([currentUser], "readwrite");
    // 打开已经存储的数据对象
    var objectStore = transaction.objectStore(currentUser);
    let request = objectStore.get(primaryKey);
    request.onsuccess = function (e) {
        if (result.success) {
            var chageData = {
                serverId: e.target.result.serverId,
                illnessId: e.target.result.illnessId, // 病例id
                userImg: e.target.result.userImg, // 用户头像
                orderEndTime: e.target.result.orderEndTime, // 门诊订单结束时间
                doctorName: e.target.result.doctorName, // 医生姓名
                fromType: e.target.result.fromType,  // 后台还是用户发送的 0是后台
                orderId: e.target.result.orderId, // 订单id
                userName: e.target.result.userName, // 问诊人姓名
                doctorImg: e.target.result.doctorImg, // 医生头像
                inquireType: e.target.result.inquireType, // inquireType 0是图文问诊 1是名医在线
                otherSide: e.target.result.otherSide, // 当前对话医生id
                createdDate: e.target.result.createdDate, // 创建消息的时间
                userType: e.target.result.userType, // 0是发送在右边, 1是接收在左边
                content: e.target.result.content, // 消息内容
                chatType: e.target.result.chatType, // 消息发送的类型0是文字 , 1是图片, 2是语音
                isRead: e.target.result.isRead // isRead判断是否为已读消息 发送消息无这个
            }
            objectStore.put(chageData);
            callback();
        }
    };
}

// 接收im消息
function addMsg(currentUser, callback) {
    var myDate = new Date;
    conn.listen({
        //收到图片消息
        onPictureMessage: function (message) {
            addBd(currentUser, {
                serverId: message.id,
                illnessId: message.ext.params.illnessId, // 病例id
                userImg: message.ext.params.userImg, // 用户头像
                orderEndTime: message.ext.params.orderEndTime, // 门诊订单结束时间
                doctorName: message.ext.params.doctorName, // 医生姓名
                fromType: message.ext.params.fromType,  // 后台还是用户发送的 0是后台
                orderId: message.ext.params.orderId || message.ext.params.orderNo, // 订单id
                userName: message.ext.params.userName, // 问诊人姓名
                doctorImg: message.ext.params.doctorImg, // 医生头像
                inquireType: message.ext.params.inquireType, // inquireType 0是图文问诊 1是名医在线
                otherSide: message.from, // 当前对话医生id
                createdDate: myDate.toLocaleString(), // 创建消息的时间
                userType: 1, // 0是发送在右边, 1是接收在左边
                content: message.url, // 消息内容
                chatType: 'image', // 消息发送的类型0是文字 , 1是图片, 2是语音
                isRead: false // isRead判断是否为已读消息, 这个页面消息全是未读
            });
            callback('text');
        },
        //收到文字
        onTextMessage: function (message) {
            addBd(currentUser, {
                serverId: message.id,
                illnessId: message.ext.params.illnessId, // 病例id
                userImg: message.ext.params.userImg, // 用户头像
                orderEndTime: message.ext.params.orderEndTime, // 门诊订单结束时间
                doctorName: message.ext.params.doctorName, // 医生姓名
                fromType: message.ext.params.fromType,  // 后台还是用户发送的 0是后台
                orderId: message.ext.params.orderId || message.ext.params.orderNo, // 订单id
                userName: message.ext.params.userName, // 问诊人姓名
                doctorImg: message.ext.params.doctorImg, // 医生头像
                inquireType: message.ext.params.inquireType, // inquireType 0是图文问诊 1是名医在线
                otherSide: message.from, // 当前对话医生id
                createdDate: myDate.toLocaleString(), // 创建消息的时间
                userType: 1, // 0是发送在右边, 1是接收在左边
                content: message.data, // 消息内容
                chatType: 'text', // 消息发送的类型0是文字 , 1是图片, 2是语音
                isRead: false // isRead判断是否为已读消息, 这个页面消息全是未读
            });
            callback('text');
        },
        // 收到音频
        onAudioMessage: function (message) {
            var options = { url: message.url };
            options.onFileDownloadComplete = function (response, type) {
                // 环线转换发送的文件一定要是blob格式
                let a = new FileReader();
                a.onload = function (e) {
                    console.log(e.target.result)
                    dataURL2Audio(e.target.result, function (entry) {
                        var toURL = entry.toURL();
                        // 环信数据存储到本地
                        addBd(currentUser, {
                            serverId: message.id,
                            illnessId: message.ext.params.illnessId, // 病例id
                            userImg: message.ext.params.userImg, // 用户头像
                            orderEndTime: message.ext.params.orderEndTime, // 门诊订单结束时间
                            doctorName: message.ext.params.doctorName, // 医生姓名
                            fromType: message.ext.params.fromType,  // 后台还是用户发送的 0是后台
                            orderId: message.ext.params.orderId || message.ext.params.orderNo, // 订单id
                            userName: message.ext.params.userName, // 问诊人姓名
                            doctorImg: message.ext.params.doctorImg, // 医生头像
                            inquireType: message.ext.params.inquireType, // inquireType 0是图文问诊 1是名医在线
                            otherSide: message.from, // 当前对话医生id
                            createdDate: myDate.toLocaleString(), // 创建消息的时间
                            userType: 1, // 0是发送在右边, 1是接收在左边
                            content: toURL, // 消息内容
                            chatType: 'sound', // 消息发送的类型0是文字 , 1是图片, 2是语音
                            isRead: false // isRead判断是否为已读消息, 这个页面消息全是未读
                        });
                    });
                }
                a.readAsDataURL(response);
            };

            options.onFileDownloadError = function (res) {
                //音频下载失败
                console.log('音频下载失败')
            };

            //通知服务器将音频转为mp3
            options.headers = {
                'Accept': 'audio/mp3'
            };

            WebIM.utils.download.call(conn, options);
        }
    });
};

